===========
miniscrapes
===========


.. image:: https://img.shields.io/pypi/v/miniscrapes.svg
        :target: https://pypi.python.org/pypi/miniscrapes

.. image:: https://img.shields.io/travis/marcua/miniscrapes.svg
        :target: https://travis-ci.com/marcua/miniscrapes

.. image:: https://readthedocs.org/projects/miniscrapes/badge/?version=latest
        :target: https://miniscrapes.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




lil' pieces of data, one miniscrape at a time


* Free software: Apache Software License 2.0
* Documentation: https://miniscrapes.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
